==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/l3vpnsvcext/rev20160730/l3vpnsvcext/bearerattachmentgrouping/DefaultBearerAttachment.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.bearerattachmentgrouping;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietfinettypes.rev20130715.yrtietfinettypes.Ipv4Address;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of bearerAttachment.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultBearerAttachment extends InnerModelObject implements BearerAttachment {
    protected String peName;
    protected Ipv4Address peMgmtIp;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String peName() {
        return peName;
    }

    @Override
    public Ipv4Address peMgmtIp() {
        return peMgmtIp;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void peName(String peName) {
        valueLeafFlags.set(LeafIdentifier.PENAME.getLeafIndex());
        this.peName = peName;
    }

    @Override
    public void peMgmtIp(Ipv4Address peMgmtIp) {
        valueLeafFlags.set(LeafIdentifier.PEMGMTIP.getLeafIndex());
        this.peMgmtIp = peMgmtIp;
    }

    @Override
    public int hashCode() {
        return Objects.hash(peName, peMgmtIp, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultBearerAttachment) {
            DefaultBearerAttachment other = (DefaultBearerAttachment) obj;
            return
                Objects.equals(peName, other.peName) &&
                Objects.equals(peMgmtIp, other.peMgmtIp) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("peName=" + peName)
            .add("peMgmtIp=" + peMgmtIp)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultBearerAttachment.
     */
    public DefaultBearerAttachment() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/l3vpnsvcext/rev20160730/l3vpnsvcext/bearerattachmentgrouping/DefaultBearerAttachment.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.bearerattachmentgrouping;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietfinettypes.rev20130715.yrtietfinettypes.Ipv4Address;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of bearerAttachment.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultBearerAttachment extends InnerModelObject implements BearerAttachment {
    protected String peName;
    protected Ipv4Address peMgmtIp;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String peName() {
        return peName;
    }

    @Override
    public Ipv4Address peMgmtIp() {
        return peMgmtIp;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void peName(String peName) {
        valueLeafFlags.set(LeafIdentifier.PENAME.getLeafIndex());
        this.peName = peName;
    }

    @Override
    public void peMgmtIp(Ipv4Address peMgmtIp) {
        valueLeafFlags.set(LeafIdentifier.PEMGMTIP.getLeafIndex());
        this.peMgmtIp = peMgmtIp;
    }

    @Override
    public int hashCode() {
        return Objects.hash(peName, peMgmtIp, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultBearerAttachment) {
            DefaultBearerAttachment other = (DefaultBearerAttachment) obj;
            return
                Objects.deepEquals(peName, other.peName) &&
                Objects.deepEquals(peMgmtIp, other.peMgmtIp) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("peName=" + peName)
            .add("peMgmtIp=" + peMgmtIp)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultBearerAttachment.
     */
    public DefaultBearerAttachment() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
